import { createTokenWriter } from '../utils/token-writer';
import { clearLocalStorage } from '../utils/ls';

const UPDATED = 'TOKEN_UPDATED';
const CLEARED = 'TOKEN_CLEARED';

export const createTokenBundle = opts => {
  const { readToken, writeToken, clearToken } = createTokenWriter(opts);
  return {
    name: 'token',
    getReducer: () => {
      const initial = {
        token: readToken()
      };
      return (state = initial, { type, payload }) => {
        if (type === UPDATED) {
          return Object.assign({}, state, { token: payload });
        }
        if (type === CLEARED) {
          return Object.assign({}, state, { token: null });
        }
        return state;
      };
    },
    selectAuthToken: state => state.token.token,
    selectIsSignedIn: state => !!state.token.token,
    doReceiveToken: token => ({ dispatch }) => {
      writeToken(token);
      dispatch({ type: UPDATED, payload: token });
    },
    doClearToken: () => ({ dispatch }) => {
      clearToken();
      clearLocalStorage();
      dispatch({ type: CLEARED });
    }
  };
};